@@ -150,7 +150,7 @@ impl Tabulate {
         self.data.push(DataOrSep::Sep(c));
     }
 
-    pub fn print(self) -> String {
+    pub fn print(self, color: bool) -> String {
         let widths = self.widths;
         let cols = self.cols;
 
@@ -174,7 +174,11 @@ impl Tabulate {
                     };
 
                     if let Some(style) = style {
-                        style.paint(s).to_string()
+                        if color {
+                            style.paint(s).to_string()
+                        } else {
+                            s
+                        }
                     } else {
                         s
                     }
@@ -234,7 +238,7 @@ mod tests {
         tabs.separator('-');
         tabs.feed(vec!["Total".into(), "".into(), "8:00:00".into(), "".into()]);
 
-        assert_eq!(Ps(&tabs.print()), Ps("\
+        assert_eq!(Ps(&tabs.print(false)), Ps("\
 Day                Start      End        Duration Notes
 Fri Oct 03, 2008   12:00:00 - 14:00:00    2:00:00 entry 1
                    16:00:00 - 18:00:00    2:00:00 entry 2
@@ -264,7 +268,7 @@ Total                                     8:00:00
         tabs.separator('-');
         tabs.feed(vec!["Total".into(),                                     "".into(), "52:00:00".into(), "".into()]);
 
-        assert_eq!(Ps(&tabs.print()), Ps("\
+        assert_eq!(Ps(&tabs.print(false)), Ps("\
 Day                Start      End         Duration Notes
 Wed Oct 01, 2008   12:00:00 - 14:00:00+2d 50:00:00 entry 1
                                           50:00:00
@@ -295,7 +299,7 @@ Total                                     52:00:00
         tabs.separator('-');
         tabs.feed(vec!["".into(), "Total".into(), "".into(), "8:00:00".into()]);
 
-        assert_eq!(Ps(&tabs.print()), Ps(" ID Day                Start      End        Duration Notes
+        assert_eq!(Ps(&tabs.print(false)), Ps(" ID Day                Start      End        Duration Notes
   1 Fri Oct 03, 2008   12:00:00 - 14:00:00    2:00:00 entry 1
   2                    16:00:00 - 18:00:00    2:00:00 entry 2
                                               4:00:00
@@ -323,7 +327,7 @@ Total                                     52:00:00
         tabs.separator('-');
         tabs.feed(vec!["".into(), "Total".into(), "".into(), "2:00:00".into()]);
 
-        assert_eq!(Ps(&tabs.print()), Ps("   ID Day                Start      End        Duration Notes
+        assert_eq!(Ps(&tabs.print(false)), Ps("   ID Day                Start      End        Duration Notes
 60000 Sun Oct 05, 2008   16:00:00 - 18:00:00    2:00:00 chatting with bob about upcoming task,
                                                         district sharing of images, how the user
                                                         settings currently works etc. Discussing the
@@ -353,7 +357,7 @@ Total                                     52:00:00
                                                       tabs.separator('-');
         tabs.feed(vec!["Total".into(),                                     "".into(), "2:00:00".into(), "".into()]);
 
-        assert_eq!(Ps(&tabs.print()), Ps("\
+        assert_eq!(Ps(&tabs.print(false)), Ps("\
 Day                Start      End        Duration Notes
 Sun Oct 05, 2008   16:00:00 - 18:00:00    2:00:00 first line
                                                   and a second line
@@ -378,7 +382,7 @@ Total                                     2:00:00
         tabs.separator('-');
         tabs.feed(vec!["Total".into(),                                     "".into(), "2:00:00".into(), "".into()]);
 
-        assert_eq!(Ps(&tabs.print()), Ps("\
+        assert_eq!(Ps(&tabs.print(false)), Ps("\
 Day                Start      End        Duration Notes
 Sun Oct 05, 2008   16:00:00 - 18:00:00    2:00:00 quiúbole
                                           2:00:00
@@ -399,7 +403,7 @@ Total                                     2:00:00
         tabs.separator('-');
         tabs.feed(vec!["ta güeno".into()]);
 
-        assert_eq!(Ps(&tabs.print()), Ps("\
+        assert_eq!(Ps(&tabs.print(false)), Ps("\
 Hola
 
 adiós
@@ -420,7 +424,7 @@ ta güeno
         tabs.feed(vec!["foo".into(), "key".into()]);
         tabs.feed(vec!["key".into(), "foo".into()]);
 
-        assert_eq!(tabs.print(), format!("\
+        assert_eq!(tabs.print(true), format!("\
 foo key
 {} foo
 ", Style::new().dimmed().paint("key")));
